@@ -1,5 +1,10 @@
 #if 0
 
+N_("Breakfast Oats Jar")
+N_("This recipe is great for those who usually don't have time for breakfast. Prepare it in mason jars/portable food containers the night before, and you can have your homemade breakfast on-the-go! Make a couple batches in advance if you know you won't have time. This recipe is also very flexible as you can make it vegan, or gluten-free simply by substituting the components i.e. dairy milk with coconut milk, honey with agave, or use gluten-free oats. Also, any fruits of your choice, fresh or frozen.")
+N_("[image:2]Add all the ingredients in a 16-oz container, or divide equally between two 8-oz containers.")
+N_("[image:0]Mix well. Cover with lid(s), and place in the refrigerator for at least 4 hours or overnight. Thanks to the chia seeds, the mixture will develop a pudding-like texture.")
+N_("[image:1]You can make ahead, but best to consume within 2-3 days.")
 N_("Kiwi-Mandarin Salsa")
 N_("This salad is a sweet and sour addition which work well to most main courses, for example lasagna. The juicy fruits inside makes it a very refreshing salad.")
 N_("[image:1]Wash the fruits and vegetables well.")
@@ -8,7 +13,7 @@ N_("[image:3]Peel the orange and cut it in pieces.")
 N_("[image:4]Cut the red pepper in thin slices.")
 N_("[image:0]Mix fruits and vegetables in a bowl.")
 N_("[image:5]Add lime as you please.")
-N_("[image:6] Enjoy!")
+N_("[image:6]Enjoy!")
 N_("Borscht")
 N_("This is a traditional soup from East and Central Europe. There are an Ukranian/Russian and a Polish version, but both a very similar so I put them together in a general recipe.")
 N_("[image:0]Over an open flame or under a broiler, roast 1 carrot and half of the onion until charred, about 3 minutes.")
@@ -19,6 +24,10 @@ N_("[image:0]When the bones are ready, strain the broth and discard the vegetabl
 N_("[image:0]Coarsely chop the remaining half onion and grate the other carrot. In a skillet, warm the butter on medium heat, then add the chopped onion and sauté until softened, about 5 minutes. Add the minced garlic and tomato paste and sauté until aromatic, about 1 minute.")
 N_("[timer:00:10:00]Add the sautéed onion and garlic paste to the broth, along with the beets, red wine vinegar, and grated carrot. Bring to a simmer on medium heat, then add the shredded cabbage and cubed potatoes. Return to a simmer and cook for 10 more minutes, skimming any excess fat from the surface, then stir in the meat, parsley, and lemon juice. Season with salt and pepper to taste, about 1/2 tsp. each.")
 N_("[image:0]Cover, remove from the heat, and allow to brew for 20 minutes. Serve with a dollop of sour cream and fresh dill sprinkled on top. For a more flavorful soup, allow the soup to brew overnight and reheat the next day.")
+N_("It's easy to convert this soup in vegan or vegetarian by not adding the meat and cream.")
+N_("It will lose a bit of personality though.")
+N_("If you're in a hurry, use a canned broil as base and add around 600 g of chopped meat without bones, and follow the rest of instruccions. This way it will be ready in less than an hour.")
+N_("Ingredients may vary. In example lemon juice instead of vinegar and ground or powder pepper instead of the peppercorns.")
 N_("Mantovana Cake")
 N_("Mantovana cake (or Torta Mantovana in Italian) is a Tuscan classic. It is simple, yet rich and delicious. Very good for breakfast - Italian style - or as snacks, accompanied with coffee or tea. A small note; the vanilla baking powder is typical in Italy for baked sweet goods, and negates the need to add vanilla extract separately to a recipe. You are fine just using regular baking powder, but remember to add 1/2 teaspoon of vanilla extract. If you can't get hold of the vanilla powdered sugar for dusting, just use the regular powdered sugar.")
 N_("[image:0]Preheat oven to [temperature:180C]. Line a 9-inch round cake pan with parchment paper and grease well.")
@@ -31,23 +40,17 @@ N_("[image:0]Let rest in the pan for 10 minutes, then invert onto a cooling rack
 N_("[image:0]Before serving, dust the top generously with vanilla powdered sugar.")
 N_("Carbonara")
 N_("\"Carbonara\" is a sauce that can be used with long pasta, like spaghetti or fettuccine.")
-N_("[image:1]")
-N_("Start by boiling about 1 litre of water for each 100g of pasta.")
-N_("[image:1]")
-N_("Once the water is boiling, pour 20g of coarse salt in it for every litre of water, and then throw the spaghetti in.")
-N_("[image:1]")
-N_("While the pasta is cooking, take a large bowl and put the parmesan cheese in it.")
-N_("[image:2]")
-N_("Add the whole egg and the yolks to the parmesan, and beat the eggs until you get a creamy sauce.")
-N_("[image:3]")
-N_("Put the guanciale in a small pan with a teaspoon of oil, and shallow fry it until the fat is transparent and the meat is crispy; then remove from the fire.")
-N_("[image:5]")
-N_("Once the pasta is ready, drain it and add it to the eggs and cheese. Then, add the guanciale.")
-N_("[image:6]")
-N_("Season with salt and pepper to your liking.")
+N_("[image:1]Start by boiling about 1 litre of water for each 100g of pasta.")
+N_("[image:1]Once the water is boiling, pour 20g of coarse salt in it for every litre of water, and then throw the spaghetti in.")
+N_("[image:1]While the pasta is cooking, take a large bowl and put the parmesan cheese in it.")
+N_("[image:2]Add the whole egg and the yolks to the parmesan, and beat the eggs until you get a creamy sauce.")
+N_("[image:3]Put the guanciale in a small pan with a teaspoon of oil, and shallow fry it until the fat is transparent and the meat is crispy; then remove from the fire.")
+N_("[image:5]Once the pasta is ready, drain it and add it to the eggs and cheese. Then, add the guanciale.")
+N_("[image:6]Season with salt and pepper to your liking.")
+N_("If you cannot find guanciale (cured pork cheek) you can substitute it with pancetta.")
 N_("Roots Pie")
 N_("This vegetable pie is my own spin off a traditional recipe. It has great taste, crusty dough and fancy colors too.")
-N_("[image:12]Turn on the oven at 200 ℃.")
+N_("[image:12]Turn on the oven at [temperature:200C].")
 N_("[image:2]Pour flour on the table, add salt. Divide the butter into small pieces and add water.")
 N_("[image:3]Use the butter, water and yoghurt to work it all into a dough.")
 N_("[image:4]Find a pie form.")
@@ -91,7 +94,7 @@ N_("This savoury cakes can be served as appetizers or as main course. There are
 N_("Prepare the batter: melt butter in a large bowl, then mix with the eggs, flour and yeast in a bowl.")
 N_("Add the ingredients matching the variation you chose, preferably sliced or diced to turn them into small bits, and mix again. Try coming up with your own variations!")
 N_("Pour the batter in a loaf tin.")
-N_("[timer:00:40:00]Put in the oven at 180°C for 40 minutes.")
+N_("[timer:00:40:00]Put in the oven at [temperature:180C] for 40 minutes.")
 N_("[image:1]Serve cold, cut in slices or cubes that people will get with a toothpick.")
 N_("Tagliatelle alla Romana")
 N_("Pasta is one of my favourite things in the world, and this is one of my favourity pasta dishes. It's gutsy Italian food at its best.")
@@ -108,15 +111,14 @@ N_("If the sauce needs loosening, add a bit of the pasta cooking water.")
 N_("Serve with plenty of black pepper.")
 N_("Non-knead buns")
 N_("Very quick fresh bread for breakfast with 5 minutes of work.")
-N_("[image:0]Preparation:")
-N_("[image:1]Mix together all of the ingredients in a large bowl into a thick porridge-like dough. Do not knead the dough, just mix it together. ")
+N_("[image:1]Preparation: Mix together all of the ingredients in a large bowl into a thick porridge-like dough. Do not knead the dough, just mix it together. ")
 N_("Cover and leave to rise in room temperature for 8-12 hours. This can be done for example the previous night so you can bake them in the morning.")
-N_("Baking:")
-N_("Heat your oven to 250 degrees Celsius.")
+N_("Baking: Heat your oven to [temperature:250C].")
 N_("[image:3]The dough will be more than double in size and full of bubbles and very sticky. Pour a generous amount of flour on your baking surface so it doesn't stick, and pour the dough over it.")
 N_("[image:4]Form the dough into a thick snake, about the diameter of your arm and cut bun-sized pieces with scissors onto the baking sheet.")
 N_("[timer:00:15:00]Bake until nice and brown, this will take approximately 15 minutes.")
 N_("[image:5]You can substitute half of the wheat flour with oats, seeds or different kind of flour if you want variety.")
+N_("[image:0]Enjoy!")
 N_("Traditional South Indian Tomato Chicken Curry, Fast Version")
 N_("A quick and easy version of a traditional South Indian chicken curry dish, learned from a Mallu immigrant and cook.")
 N_("Preparation:")
@@ -141,7 +143,7 @@ N_("4 cloves garlic = 1/2 tsp powdered garlic")
 N_("8 oz cream cheese = 1 pouch")
 N_("1 cup half and half = one small carton")
 N_("1 cup grated parmesan = 1 small bag")
-N_("Preheat oven to 350°F.")
+N_("Preheat oven to [temperature:350F].")
 N_("Butter a 13x9 baking dish.")
 N_("Into buttered baking dish:")
 N_("- Add 5 thinly sliced (use a mandoline) russet potatoes, or 5 cans rinsed pre-sliced potatoes.")
@@ -163,10 +165,10 @@ N_("Classic Chicken Noodle Soup")
 N_("A simple take on a typical American meal.")
 N_("If you haven't butchered the chicken, do so. Depending on how meaty you want the soup, you can use more or less of the butchered parts (I recommend the dark leg meat for the soup). Use the remaining parts for another dish.")
 N_("Wash the celery, carrots and herbs. Slice the carrots and celery. Coarsely chop the onion. Prepare the herbs using kitchen twine in a bouquet garni.")
-N_("In a large pot, add the chicken, the stock, 2 carrots, 1 stalk of celery, the onion and the bouquet garni. Fill the pot with water to cover the chicken. Bring to a boil and simmer for at least 2 hours.")
+N_("[timer:02:00:00]In a large pot, add the chicken, the stock, 2 carrots, 1 stalk of celery, the onion and the bouquet garni. Fill the pot with water to cover the chicken. Bring to a boil and simmer for at least 2 hours.")
 N_("Using a cheese cloth strainer, strain the soup into another pot. Remove meat from the bones, gather any loose chicken and add it to the strained soup. Discard the bones and cooked vegetables.")
 N_("Add the remaining carrots and celery to the soup. Bring to a boil and simmer for at least one hour. Season with salt and pepper to taste.")
-N_("Add noodles and simmer for about 10 minutes, until the noodles are done.")
+N_("[timer:00:10:00]Add noodles and simmer for about 10 minutes, until the noodles are done.")
 N_("Pizzaburger")
 N_("Tomato dough with hamburger and cheese topping")
 N_("Dissolve yeast in warm water. Let stand for 2 minutes.")
@@ -178,18 +180,18 @@ N_("Add remaining 1 1/2 cups tomato sauce, salt, pepper, and 2 tsp chili powder.
 N_("Remove from heat.")
 N_("Spread dough on greased cookie sheet (will be somewhat springy and pull back as it is spread out).")
 N_("Top with hamburger mixture and cover with cheese slices.")
-N_("Bake at 400 for 20 to 30 minutes until dough is baked.")
+N_("[timer:00:20:00]Bake at [temperature:400F] for 20 to 30 minutes until dough is baked.")
 N_("Pineapple Upside Down Cake with Hot Buttered Rum Sauce")
 N_("This is a delicious, boozy update on a classic cake. The combination of rum and pineapple gives it a distinctively Caribbean flavour.")
-N_("Preheat the oven to 175°C/gas mark 4.")
-N_("Grease a round 20cm cake tin.")
+N_("Preheat the oven to [temperature:175C] (gas mark 4).")
+N_("Grease a round 20 cm cake tin.")
 N_("Line the bottom of the tin with as many whole pineapple rings as will fit. Cut the remaining rings in half and use them to line the sides of the tin.")
 N_("Crack the eggs into a bowl and add the caster sugar. Whisk until pale and light (an electric whisk is good for this, but not essential).")
 N_("In a different bowl, combine the flour and baking powder, and then sift into the egg and sugar mixture, mixing as you go.")
-N_("Melt the butter and combine with the milk,  rum and vanilla extract. Zest half the lemon and add.")
+N_("Melt the butter and combine with the milk, rum and vanilla extract. Zest half the lemon and add.")
 N_("Mix the wet mixture into the rest of the ingredients.")
-N_("Poor the cake mixture into the cake tin and bake for around 40 minutes, until the top is light brown and an inserted skewer comes out clean.")
-N_("Leave the cake to cool for 5 minutes, then turn out on to a rack to cool completely.")
+N_("[timer:00:40:00]Poor the cake mixture into the cake tin and bake for around 40 minutes, until the top is light brown and an inserted skewer comes out clean.")
+N_("[timer:00:05:00]Leave the cake to cool for 5 minutes, then turn out on to a rack to cool completely.")
 N_("When it's time to eat, make the sauce: combine the muscovado sugar and cream in a saucepan and heat until the sugar has dissolved. Add the rum and simmer until it has thickened a little, then add the butter and let it melt into the sauce.")
 N_("Pour the hot sauce over the cake and serve.")
 N_("Pan pizza")
@@ -200,10 +202,10 @@ N_("The next day it should have rosen quite a bit. Dump it all out onto a floure
 N_("Spread olive oil in a 10-inch cast iron skillet or round cake pan and place a dough ball in the middle.")
 N_("Rub the dough ball around and flip it a couple times until it is completely coated in oil and the oil completely coats the bottom and sides of the pan. Cover in plastic, and let it sit for another couple of hours without touching it.")
 N_("The dough should have spread on it own (takes about 2 hours). Lift the sides of the dough to let big air bubbles out.")
-N_("Put in the oven at 280°C. (or as hot as your oven goes) for about 15 minutes. Peek underneath and if your pizza is a little pale, you can finish on the stovetop directly over medium heat until it is as dark and crisp as you like it.")
+N_("Put in the oven at [temperature:280C]. (or as hot as your oven goes) for about 15 minutes. Peek underneath and if your pizza is a little pale, you can finish on the stovetop directly over medium heat until it is as dark and crisp as you like it.")
 N_("Wholesome Crackers")
 N_("Crackers are a fulfilling alternative snack and keeps your stomach going. Crackers consist of seeds, oat and flour. The recipe described here is very flexible. You can use whichever seeds, nuts and flour types you may have. I've personally tried almonds, sesame seeds, chia seeds, rye grains, millet and  buckwheat.")
-N_("Turn on the oven at 473,15 K (200 °C). Mix all dry ingredients (seeds, flour, oatmeal, baking powder and salt) together. Mix oil. Then add water gradually while mixing until the dough is firm and pasty. If you add too much water, the dough will end up sticking too much to the baking paper.")
+N_("Turn on the oven at [temperature:200C]. Mix all dry ingredients (seeds, flour, oatmeal, baking powder and salt) together. Mix oil. Then add water gradually while mixing until the dough is firm and pasty. If you add too much water, the dough will end up sticking too much to the baking paper.")
 N_("Cut a sheet of baking paper at the size of a baking tray and place the dough on it. Cut another sheet of baking paper and put on top. Use a rolling pin on top of the second baking sheet to flatten the dough. Make the dough as thing as possible. Afterwards, take off the second sheet. Bring forth a knife and cut creases from horizontally and vertically to form squares (see example on the picture). Optionally decorate with extra seeds on top before inserting into the preheated oven.")
 N_("Wait for the crackers to become crisp, this takes around 17 minutes. You can check if they are done by touching the crackers or by pulling up a bit in the baking sheet and see if the crackers in the middle still bends.  The crackers take on a yellow golden color when they are done.")
 N_("Take out the crackers and leave them on the kitchen table to cool down for a few minutes.")
@@ -219,7 +221,7 @@ N_("[image:2]Mix the flour with the baking powder and mix it in. Separate a thir
 N_("[image:4]Spread the light dough on a buttered baking sheet. Put the dark dough on top.")
 N_("[image:4]Use a fork to make a wavy pattern.")
 N_("[image:6]Spread the dried cherries on top of the dough.")
-N_("[timer:00:30:00]Bake for 30 minutes at 200 °C.")
+N_("[timer:00:30:00]Bake for 30 minutes at [temperature:200C].")
 N_("[image:7]Use the milk, sugar and pudding to cook vanilla pudding and let it cool down while stirring it frequently. Slowly add spoonfuls of the butter, which should be at room temperature.")
 N_("[image:8]Spread the butter cream on the cooled cake.")
 N_("[image:9]Melt the chocolate frosting in a hot water bath and sprinkle it on top.")
