@@ -268,13 +268,19 @@ visible_page_changed (GrWindow *window)
                 g_signal_handlers_block_by_func (window->search_bar, search_changed, window);
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (window->search_button), FALSE);
                 g_signal_handlers_unblock_by_func (window->search_bar, search_changed, window);
-                gtk_header_bar_set_title (GTK_HEADER_BAR (window->header), _("Recipes"));
         }
 
         if (strcmp (visible, "edit") != 0) {
                 gr_edit_page_clear (GR_EDIT_PAGE (window->edit_page));
         }
 
+        if (strcmp (visible, "chef") == 0) {
+                gr_list_page_repopulate (GR_LIST_PAGE (window->chef_page));
+        }
+        else {
+                gr_list_page_clear (GR_LIST_PAGE (window->chef_page));
+        }
+
         if (strcmp (visible, "list") == 0) {
                 gr_list_page_repopulate (GR_LIST_PAGE (window->list_page));
         }
